@@ -431,7 +431,7 @@ init_gnome_version_stuff (void)
 	xmlDoc *doc;
 	char *xml_file;
 	xmlNode *node;
-	char *platform, *minor, *micro, *distributor;
+	char *platform, *minor, *micro, *distributor, *date;
 
 
 	druid_data.gnome_version = g_getenv ("BUG_BUDDY_GNOME_VERSION");
@@ -458,6 +458,8 @@ init_gnome_version_stuff (void)
 			micro = xmlNodeGetContent (node);
 		else if (!strcmp (node->name, "distributor"))
 			distributor = xmlNodeGetContent (node);
+		else if (!strcmp (node->name, "date"))
+			date = xmlNodeGetContent (node);
 	}
 	
 	if (platform && minor && micro)
@@ -466,10 +468,14 @@ init_gnome_version_stuff (void)
 	if (distributor && *distributor)
 		druid_data.gnome_distributor = g_strdup (distributor);
 	
+	if (date && *date)
+		druid_data.gnome_date = g_strdup (date);
+
 	xmlFree (platform);
 	xmlFree (minor);
 	xmlFree (micro);
 	xmlFree (distributor);
+	xmlFree (date);
 	
 	xmlFreeDoc (doc);
 }
@@ -709,7 +715,7 @@ main (int argc, char *argv[])
 			gtk_widget_destroy (GET_WIDGET ("update-dialog"));
 		}
 	}
-	
+
 	load_bugzilla_xml ();
 
 	gtk_widget_show (GET_WIDGET ("druid-window"));
